]> AND Private Git Repository - loba.git/commitdiff
Logo AND Algorithmique Numérique Distribuée

Private GIT Repository
Add option -X <double>, for testing and/or debugging purpose.
authorArnaud Giersch <arnaud.giersch@iut-bm.univ-fcomte.fr>
Thu, 22 Sep 2011 14:28:55 +0000 (16:28 +0200)
committerArnaud Giersch <arnaud.giersch@iut-bm.univ-fcomte.fr>
Thu, 22 Sep 2011 14:28:55 +0000 (16:28 +0200)
options.cpp
options.h

index 908a797f0048849a2b3e5ea641d8137b09024386..a943339eb6051560af6eba481ae1dbdb858cce4e 100644 (file)
@@ -37,7 +37,8 @@ namespace opt {
     std::string program_name;
     int help_requested = 0;
     bool version_requested = false;
     std::string program_name;
     int help_requested = 0;
     bool version_requested = false;
-    int option_x = 0;           // hidden option, for debugging purpose
+    int option_x = 0;           // hidden option (int)
+    double option_X = 0.0;      // hidden option (double)
 
     // Simulation parameters
     int log_rate = 1;
 
     // Simulation parameters
     int log_rate = 1;
@@ -229,7 +230,8 @@ bool opt::parse_args(int* argc, char* argv[])
     int c;
     opterr = 0;
     while ((c = getopt(*argc, argv,
     int c;
     opterr = 0;
     while ((c = getopt(*argc, argv,
-                       "a:bc:C:d:D:eEhi:I:l:L:m:M:N:r:Rs:S:t:T:vVx:Z")) != -1) {
+                       "a:bc:C:d:D:eEhi:I:l:L:m:M:N:r:Rs:S:t:T:vVx:X:Z"))
+           != -1) {
         switch (c) {
         case 'a':
             opt::loba_algo = optarg;
         switch (c) {
         case 'a':
             opt::loba_algo = optarg;
@@ -328,6 +330,10 @@ bool opt::parse_args(int* argc, char* argv[])
             PARSE_ARG(opt::option_x);
             XBT_WARN("option_x set to %d", opt::option_x);
             break;
             PARSE_ARG(opt::option_x);
             XBT_WARN("option_x set to %d", opt::option_x);
             break;
+        case 'X':
+            PARSE_ARG(opt::option_X);
+            XBT_WARN("option_X set to %g", opt::option_X);
+            break;
         case 'Z':
             opt::integer_transfer = !opt::integer_transfer;
             break;
         case 'Z':
             opt::integer_transfer = !opt::integer_transfer;
             break;
@@ -540,6 +546,12 @@ void opt::usage()
     if (opt::help_requested < 3)
         return;
 
     if (opt::help_requested < 3)
         return;
 
+    std::clog << "\nHidden options:\n";
+    std::clog << o("-x value") << "value is an integer"
+              << " [" << opt::option_x << "]\n";
+    std::clog << o("-X value") << "value is a real number"
+              << " [" << opt::option_X << "]\n";
+
     std::clog << "\nLogging support:\n"
               << "    See SimGrid documentation on:\n"
               << "        http://simgrid.gforge.inria.fr/doc/group__XBT__log.html#log_user\n"
     std::clog << "\nLogging support:\n"
               << "    See SimGrid documentation on:\n"
               << "        http://simgrid.gforge.inria.fr/doc/group__XBT__log.html#log_user\n"
index ed32b85e42271b9708e8c3a5b11260f3a093bdc2..89a3f1285ce44b91a9c045ad2247ecb48d1eab92 100644 (file)
--- a/options.h
+++ b/options.h
@@ -20,7 +20,8 @@ namespace opt {
     extern std::string program_name;
     extern int help_requested;
     extern bool version_requested;
     extern std::string program_name;
     extern int help_requested;
     extern bool version_requested;
-    extern int option_x;       // hidden option, for debugging purpose
+    extern int option_x;       // hidden option (int), for testing
+    extern double option_X;    // hidden option (double), for testing
 
     // Simulation parameters
     extern int log_rate;
 
     // Simulation parameters
     extern int log_rate;